@@ -10,7 +10,6 @@ oneTimeSetUp() {
     source "$test_dir/../virtualenvwrapper.sh"
     mkvirtualenv cd-test >/dev/null 2>&1
     deactivate
-    alias cd='fail "Should not be using override cd function"'
 }
 
 oneTimeTearDown() {
@@ -27,10 +26,27 @@ tearDown () {
 }
 
 test_cd() {
+    alias cd='fail "Should not be using override cd function"'
     start_dir="$(pwd)"
     virtualenvwrapper_cd "$VIRTUAL_ENV"
     assertSame "$VIRTUAL_ENV" "$(pwd)"
     virtualenvwrapper_cd "$start_dir"
+    unalias cd
+}
+
+# Define hook function to make cd break
+chpwd () {
+  return 1
+}
+# Run a test that uses cd to ensure the hook is not called
+test_cd_zsh_chpwd_not_called () {
+    if [ -n "$ZSH_VERSION" ]; then
+        start_dir="$(pwd)"
+        virtualenvwrapper_cd "$VIRTUAL_ENV"
+        assertSame "$VIRTUAL_ENV" "$(pwd)"
+        virtualenvwrapper_cd "$start_dir"
+    fi
+    unset -f chpwd >/dev/null 2>&1
 }
 
 . "$test_dir/shunit2"
