@@ -28,6 +28,21 @@ test_create() {
     done
 }
 
+test_create_space_in_name() {
+    # Only test with leading and internal spaces. Directory names with trailing spaces are legal,
+    # and work with virtualenv on OSX, but error out on Linux.
+    mkvirtualenv " env with space" >/dev/null 2>&1
+    assertTrue "Environment directory was not created" "[ -d \"$WORKON_HOME/ env with space\" ]"
+    for hook in postactivate predeactivate postdeactivate
+    do
+        assertTrue "$hook was not created" "[ -f \"$WORKON_HOME/ env with space/bin/$hook\" ]"
+        assertFalse "$hook is executable" "[ -x \"$WORKON_HOME/ env with space/bin/$hook\" ]"
+    done
+    assertTrue virtualenvwrapper_verify_active_environment
+    env_name=$(basename "$VIRTUAL_ENV")
+    assertSame " env with space" "$env_name"
+}
+
 test_activates () {
     mkvirtualenv "env2" >/dev/null 2>&1
     assertTrue virtualenvwrapper_verify_active_environment
@@ -196,7 +211,7 @@ test_mkvirtualenv_python_short_option () {
     typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
     VIRTUALENVWRAPPER_VIRTUALENV=echo
     output="$(mkvirtualenv -p python foo)"
-    assertSame "--python=$(pwd)/python foo" "$output"
+    assertSame "--python=python foo" "$output"
     VIRTUALENVWRAPPER_VIRTUALENV=$_save
 }
 
@@ -204,7 +219,7 @@ test_mkvirtualenv_python_long_option () {
     typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
     VIRTUALENVWRAPPER_VIRTUALENV=echo
     output="$(mkvirtualenv --python python foo)"
-    assertSame "--python=$(pwd)/python foo" "$output"
+    assertSame "--python=python foo" "$output"
     VIRTUALENVWRAPPER_VIRTUALENV=$_save
 }
 
@@ -212,7 +227,7 @@ test_mkvirtualenv_python_long_option_equal () {
     typeset _save=$VIRTUALENVWRAPPER_VIRTUALENV
     VIRTUALENVWRAPPER_VIRTUALENV=echo
     output="$(mkvirtualenv --python=python foo)"
-    assertSame "--python=$(pwd)/python foo" "$output"
+    assertSame "--python=python foo" "$output"
     VIRTUALENVWRAPPER_VIRTUALENV=$_save
 }
 
